@@ -88,19 +88,19 @@ class LsaDecryptor_NT6(PackageDecryptor):
 				self.log('HARD_KEY data:\n%s' % hexdump(kbk.hardkey.data))
 				return kbk.hardkey.data
 
-	def decrypt(self, encrypted):
+	def decrypt(self, encrypted, segment_size=128):
 		# TODO: NT version specific, move from here in subclasses.
 		cleartext = b''
 		size = len(encrypted)
 		if size:
 			if size % 8:
-				logger.debug('AES-CFB')
+				logger.debug('AES-CFB - %s' % size)
 				if not self.aes_key or not self.iv:
 					return cleartext
-				cipher = AES(self.aes_key, MODE_CFB, IV = self.iv, segment_size=128)
+				cipher = AES(self.aes_key, MODE_CFB, IV = self.iv, segment_size=segment_size)
 				cleartext = cipher.decrypt(encrypted)
 			else:
-				logger.debug('TDES')
+				logger.debug('TDES - size %s' % size)
 				if not self.des_key or not self.iv:
 					return cleartext
 				cipher = TDES(self.des_key, MODE_CBC, self.iv[:8])
