@@ -35,11 +35,17 @@ class WdigestTemplate(PackageTemplate):
 				template.primary_offset = 48
 				template.list_entry = PWdigestListEntry
 
-			elif sysinfo.buildnumber >= WindowsMinBuild.WIN_VISTA.value:
+			elif WindowsMinBuild.WIN_VISTA.value <= sysinfo.buildnumber < WindowsMinBuild.WIN_11.value:
 				template.signature = b'\x48\x3b\xd9\x74'
 				template.first_entry_offset = -4
 				template.primary_offset = 48
 				template.list_entry = PWdigestListEntry
+
+			elif sysinfo.buildnumber >= WindowsMinBuild.WIN_11.value:
+				template.signature = b'\x48\x3b\xd8\x74'
+				template.first_entry_offset = -4
+				template.primary_offset = 48
+				template.list_entry = PWdigestListEntry
 				
 			else:
 				raise Exception('Could not identify template! Architecture: %s sysinfo.buildnumber: %s' % (sysinfo.architecture, sysinfo.buildnumber))
@@ -114,4 +120,4 @@ class WdigestListEntry:
 		self.usage_count = ULONG(reader)
 		reader.align() #8?
 		self.this_entry = PWdigestListEntry(reader)
-		self.luid = LUID(reader).value
\ No newline at end of file
+		self.luid = LUID(reader).value
