@@ -17,7 +17,7 @@ class CryptoCMDHelper:
 		crypto_subparsers.dest = 'crypto_module'
 
 		group = crypto_subparsers.add_parser('nt', help='Generates NT hash of the password')
-		group.add_argument('password', help= 'Password to be hashed')	
+		group.add_argument('password', help= 'Password to be hashed')
 		
 		group = crypto_subparsers.add_parser('lm', help='Generates LM hash of the password')
 		group.add_argument('password', help= 'Password to be hashed')
@@ -33,6 +33,10 @@ class CryptoCMDHelper:
 		
 		group = crypto_subparsers.add_parser('gppass', help='Decrypt GP passwords')
 		group.add_argument('enc', help='Encrypted password string')
+
+		group = crypto_subparsers.add_parser('ofscan', help='Decrypt TrendMicro OfficeScan config file')
+		group.add_argument('enc', help='Encrypted password string or path to ofcscan.ini file')
+		
 		
 	def execute(self, args):
 		if args.command in self.keywords:
@@ -44,6 +48,7 @@ class CryptoCMDHelper:
 	def run(self, args):
 		from pypykatz.utils.crypto.winhash import NT, LM, MSDCC, MSDCCv2
 		from pypykatz.utils.crypto.gppassword import gppassword
+		from pypykatz.utils.crypto.ofcdecrypt import ofscan_decrypt_data
 
 		if args.crypto_module == 'nt':
 			print(NT(args.password).hex())
@@ -59,4 +64,7 @@ class CryptoCMDHelper:
 			
 		elif args.crypto_module == 'gppass':
 			print(gppassword(args.enc))
-		
\ No newline at end of file
+		
+		elif args.crypto_module == 'ofscan':
+			for param, res in ofscan_decrypt_data(args.enc):
+				print('%s: %s' % (param, res))
\ No newline at end of file
